@@ -41,16 +41,16 @@ def life_annuity(i=I, population=POPULATION, x=X, n=N, due=True, f=F, lifespan=L
     Dx = D(i, population[x], x)
     if due:  
         assert x + n + f <= lifespan, '契約終了前に最終年齢を迎えてしまいます'
-        Nx = N(i, population[x + f :], x + f, lifespan)
-        Nx_n = N(i, population[x + n + f :], x + n + f, lifespan)
+        Nx = Nc(i, population[x + f :], x + f, lifespan)
+        Nx_n = Nc(i, population[x + n + f :], x + n + f, lifespan)
         a = (Nx - Nx_n) / Dx
 
         return a
 
     else:
         assert x + n + f + 1 <= lifespan, '契約終了前に最終年齢を迎えてしまいます'
-        Nx_1 = N(i, population[x + f + 1 :], x + f + 1, lifespan)
-        Nx_n1 = N(i, population[x + n + f + 1 :], x + n + f + 1, lifespan)
+        Nx_1 = Nc(i, population[x + f + 1 :], x + f + 1, lifespan)
+        Nx_n1 = Nc(i, population[x + n + f + 1 :], x + n + f + 1, lifespan)
         a = (Nx_1 - Nx_n1) / Dx
 
         return a
@@ -87,14 +87,14 @@ def lifelong_annuity(i=I, population=POPULATION, x=X, due=True, f=F, lifespan=LI
     Dx = D(i, population[x], x)
     if due:
         assert x + f <= lifespan, '契約終了前に最終年齢を迎えてしまいます'
-        Nx = N(i, population[x + f :], x + f, lifespan)
+        Nx = Nc(i, population[x + f :], x + f, lifespan)
         a = Nx / Dx
 
         return a
 
     else:
         assert x + f + 1 <= lifespan, '契約終了前に最終年齢を迎えてしまいます'
-        Nx_1 = N(i, population[x + f + 1 :], x + f + 1, lifespan)
+        Nx_1 = Nc(i, population[x + f + 1 :], x + f + 1, lifespan)
         a = Nx_1 / Dx
 
         return a
@@ -134,7 +134,7 @@ def increasing_life_annuity(i=I, population=POPULATION, x=X, n=N, due=True, f=F,
         assert x + f + n <= lifespan, '契約終了前に最終年齢を迎えてしまいます'
         Sx = S(i, population[x + f :], x + f, lifespan)
         Sx_n = S(i, population[x + f + n :], x + f + n, lifespan)
-        Nx_n = N(i, population[x + f + n :], x + f + n, lifespan)
+        Nx_n = Nc(i, population[x + f + n :], x + f + n, lifespan)
         Ia = (Sx - Sx_n - n * Nx_n) / Dx
 
         return Ia
@@ -143,7 +143,7 @@ def increasing_life_annuity(i=I, population=POPULATION, x=X, n=N, due=True, f=F,
         assert x + f + n + 1 <= lifespan, '契約終了前に最終年齢を迎えてしまいます'
         Sx_1 = S(i, population[x + f + 1 :], x + f + 1, lifespan)
         Sx_n1 = S(i, population[x + f + n + 1 :], x + f + n + 1, lifespan)
-        Nx_n1 = N(i, population[x + f + n + 1 :], x + f + n + 1, lifespan)
+        Nx_n1 = Nc(i, population[x + f + n + 1 :], x + f + n + 1, lifespan)
         Ia = (Sx_1 - Sx_n1 - n * Nx_n1) / Dx
 
         return Ia
@@ -231,7 +231,7 @@ def decreasing_life_annuity(i=I, population=POPULATION, x=X, n=N , due=True, f=F
         assert x + f + n + 1 <= lifespan, '契約終了前に最終年齢を迎えてしまいます'
         Sx_1 = S(i, population[x + f + 1 :], x + f + 1, lifespan)
         Sx_n1 = S(i, population[x + f + n + 1 :], x + f + n + 1, lifespan)
-        Nx = N(i, population[x + f:], x + f, lifespan)
+        Nx = Nc(i, population[x + f:], x + f, lifespan)
         Ia = (n * Nx - Sx_1 + Sx_n1) / Dx
 
         return Ia
@@ -240,7 +240,7 @@ def decreasing_life_annuity(i=I, population=POPULATION, x=X, n=N , due=True, f=F
         assert x + f + n + 2 <= lifespan, '契約終了前に最終年齢を迎えてしまいます'
         Sx_2 = S(i, population[x + f + 2 :], x + f + 2, lifespan)
         Sx_n2 = S(i, population[x + f + n + 2 :], x + f + n + 2, lifespan)
-        Nx_1 = N(i, population[x + f + 1 :], x + f + 1, lifespan)
+        Nx_1 = Nc(i, population[x + f + 1 :], x + f + 1, lifespan)
         Ia = (n * Nx_1 - Sx_2 + Sx_n2) / Dx
         
         return Ia
\ No newline at end of file
