@@ -30,7 +30,7 @@ def D(i, population, x):
     return D
 
 
-def N(i, population, x, lifespan=112):
+def Nc(i, population, x, lifespan=112):
     """
     Nxを実装
     x年から最終年齢までの、Dxの和
